@@ -35,9 +35,9 @@ import os, webbrowser, sys, time, logging, shutil, re
 log = logging.getLogger("App")
 
 # Internal version used by updater (if enabled)
-INTERNAL_VERSION		= "v0.9.2.7"
+INTERNAL_VERSION		= "v0.9.3"
 # Minimal Syncthing version supported by App
-MIN_ST_VERSION			= "0.13.0"
+MIN_ST_VERSION			= "0.14.40"
 
 COLOR_DEVICE			= "#707070"					# Dark-gray
 COLOR_DEVICE_SYNCING	= "#2A89C8"					# Blue
@@ -358,7 +358,7 @@ class App(Gtk.Application, TimerManager):
 			if self.home_dir_override:
 				self.daemon = Daemon(os.path.join(self.home_dir_override, "config.xml"))
 			else:
-				self.daemon = Daemon(self.home_dir_override)
+				self.daemon = Daemon()
 		except InvalidConfigurationException, e:
 			# Syncthing is not configured, most likely never launched.
 			# Run wizard.
@@ -1043,11 +1043,14 @@ class App(Gtk.Application, TimerManager):
 	def cb_syncthing_folder_data_changed(self, daemon, rid, data):
 		if rid in self.folders:	# Should be always
 			folder = self.folders[rid]
-			folder["global"] = "%s %s, %s" % (data["globalFiles"], _("Files"), sizeof_fmt(data["globalBytes"]))
-			folder["local"]	 = "%s %s, %s" % (data["localFiles"], _("Files"), sizeof_fmt(data["localBytes"]))
-			folder["oos"]	 = "%s %s, %s" % (data["needFiles"], _("Files"), sizeof_fmt(data["needBytes"]))
+			global_files = data["globalFiles"] + data["globalSymlinks"]
+			local_files = data["localFiles"] + data["localSymlinks"]
+			need_files = data["needFiles"] + data["needSymlinks"]
+			folder["global"] = "%s %s, %s" % (global_files, _("Files"), sizeof_fmt(data["globalBytes"]))
+			folder["local"]	 = "%s %s, %s" % (local_files, _("Files"), sizeof_fmt(data["localBytes"]))
+			folder["oos"]	 = "%s %s, %s" % (need_files, _("Files"), sizeof_fmt(data["needBytes"]))
 			if folder["b_master"]:
-				can_override = (data["needFiles"] > 0)
+				can_override = (need_files > 0)
 				if can_override != folder["can_override"]:
 					folder["can_override"] = can_override
 					self.cb_syncthing_folder_up_to_date(None, rid)
